from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from proto.hdmap_lib.proto import poi_pb2

class PoiImpl:
  def __init__(self) -> None:
    self._id = 0
    self._type = poi_pb2.Poi.PoiType.POI_QUEUE_REGION
    self._name = ""
    self._coordinate = Vec2d()
    self._lanes:list[RelationImpl] = []
    self._pull_over_regions:list[RelationImpl] = []
    self._parking_spaces:list[RelationImpl] = []
    
  def id(self):
    return self._id
  
  def type(self):
    return self._type
  
  def name(self):
    return self._name
  
  def coordinate(self):
    return self._coordinate
  
  def lanes(self):
    return self._lanes
  
  def pull_over_regions(self):
    return self._pull_over_regions
  
  def parking_spaces(self):
    return self._parking_spaces


from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from pyhdmap.remote.hdmap_impl.geometry import CurveImpl

class LanePoint:
  def __init__(self, lane_id, s) -> None:
    self._lane_id = lane_id
    self._s = s
    
  def lane_id(self):
    return self._lane_id
  
  def s(self):
    return self._s

class ParkingSpaceImpl:
  def __init__(self) -> None:
    self._id = 0
    self._left_boundary = CurveImpl()
    self._right_boundary = CurveImpl()
    self._central_line:list[Vec2d] = []
    self._reference_line = None
    self._polygon = Polygon2d()
    self._in_lanes:list[LanePoint] = []
    self._out_lanes:list[LanePoint] = []
    self._pois:list[RelationImpl] = []
    
  def id(self):
    return self._id
  
  def left_boundary(self):
    return self._left_boundary
  
  def right_boundary(self):
    return self._right_boundary
  
  def reference_line(self):
    if self._reference_line == None:
      Utils.BuildReferenceLineFromPoints(self._central_line, self._reference_line)
    return self._reference_line
  
  def polygon(self):
    return self._polygon
  
  def in_lanes(self):
    return self._in_lanes
  
  def out_lanes(self):
    return self._out_lanes
  
  def pois(self):
    return self._pois



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/signal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/signal.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"proto/hdmap_lib/proto/signal.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\"\xd4\x04\n\x06Signal\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12;\n\x10\x63ombination_type\x18\x02 \x01(\x0e\x32!.hdmap_lib.Signal.CombinationType\x12\x31\n\x0bsignal_type\x18\x03 \x01(\x0e\x32\x1c.hdmap_lib.Signal.SignalType\x12$\n\x08\x62oundary\x18\x04 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x12\"\n\x06\x63\x65nter\x18\x05 \x01(\x0b\x32\x12.hdmap_lib.Point3D\"\x8a\x01\n\x0f\x43ombinationType\x12\x17\n\x13UNKNOWN_COMNINATION\x10\x01\x12\x14\n\x10MIX_2_HORIZONTAL\x10\x02\x12\x12\n\x0eMIX_2_VERTICAL\x10\x03\x12\x14\n\x10MIX_3_HORIZONTAL\x10\x04\x12\x12\n\x0eMIX_3_VERTICAL\x10\x05\x12\n\n\x06SINGLE\x10\x06\"\xe7\x01\n\nSignalType\x12\x12\n\x0eUNKNOWN_SIGNAL\x10\x01\x12\n\n\x06\x43IRCLE\x10\x02\x12\x0e\n\nARROW_LEFT\x10\x03\x12\x11\n\rARROW_FORWARD\x10\x04\x12\x0f\n\x0b\x41RROW_RIGHT\x10\x05\x12\x1a\n\x16\x41RROW_LEFT_AND_FORWARD\x10\x06\x12\x1b\n\x17\x41RROW_RIGHT_AND_FORWARD\x10\x07\x12\x10\n\x0c\x41RROW_U_TURN\x10\x08\x12\x19\n\x15\x41RROW_LEFT_AND_U_TURN\x10\t\x12\r\n\tCOUNTDOWN\x10\n\x12\x10\n\x0cWAITING_AREA\x10\x0b'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_SIGNAL_COMBINATIONTYPE = _descriptor.EnumDescriptor(
  name='CombinationType',
  full_name='hdmap_lib.Signal.CombinationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_COMNINATION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_2_HORIZONTAL', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_2_VERTICAL', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_3_HORIZONTAL', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIX_3_VERTICAL', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=344,
  serialized_end=482,
)
_sym_db.RegisterEnumDescriptor(_SIGNAL_COMBINATIONTYPE)

_SIGNAL_SIGNALTYPE = _descriptor.EnumDescriptor(
  name='SignalType',
  full_name='hdmap_lib.Signal.SignalType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SIGNAL', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CIRCLE', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_LEFT', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_FORWARD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_RIGHT', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_LEFT_AND_FORWARD', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_RIGHT_AND_FORWARD', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_U_TURN', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_LEFT_AND_U_TURN', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNTDOWN', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING_AREA', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=485,
  serialized_end=716,
)
_sym_db.RegisterEnumDescriptor(_SIGNAL_SIGNALTYPE)


_SIGNAL = _descriptor.Descriptor(
  name='Signal',
  full_name='hdmap_lib.Signal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Signal.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='combination_type', full_name='hdmap_lib.Signal.combination_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_type', full_name='hdmap_lib.Signal.signal_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary', full_name='hdmap_lib.Signal.boundary', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center', full_name='hdmap_lib.Signal.center', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNAL_COMBINATIONTYPE,
    _SIGNAL_SIGNALTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=716,
)

_SIGNAL.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_SIGNAL.fields_by_name['combination_type'].enum_type = _SIGNAL_COMBINATIONTYPE
_SIGNAL.fields_by_name['signal_type'].enum_type = _SIGNAL_SIGNALTYPE
_SIGNAL.fields_by_name['boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_SIGNAL.fields_by_name['center'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POINT3D
_SIGNAL_COMBINATIONTYPE.containing_type = _SIGNAL
_SIGNAL_SIGNALTYPE.containing_type = _SIGNAL
DESCRIPTOR.message_types_by_name['Signal'] = _SIGNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), {
  'DESCRIPTOR' : _SIGNAL,
  '__module__' : 'proto.hdmap_lib.proto.signal_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Signal)
  })
_sym_db.RegisterMessage(Signal)


# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from proto.grpc import hdmapimpl_pb2 as proto_dot_grpc_dot_hdmapimpl__pb2


class HdmapImplStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LoadMap = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/LoadMap',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapReply.FromString,
                )
        self.ReleaseMap = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/ReleaseMap',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapReply.FromString,
                )
        self.Reload = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/Reload',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadReply.FromString,
                )
        self.GetMap = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetMap',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapReply.FromString,
                )
        self.GetElementById = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetElementById',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdReply.FromString,
                )
        self.GetElements = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetElements',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsReply.FromString,
                )
        self.Getprojection = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/Getprojection',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionReply.FromString,
                )
        self.GetPoint = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetPoint',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointReply.FromString,
                )
        self.GetHeading = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetHeading',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingReply.FromString,
                )
        self.GetWidth = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetWidth',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthReply.FromString,
                )
        self.GetRoadWidth = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetRoadWidth',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthReply.FromString,
                )
        self.GetRelativeWidth = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetRelativeWidth',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthReply.FromString,
                )


class HdmapImplServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LoadMap(self, request, context):
        """hdmap interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReleaseMap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetElementById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetElements(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Getprojection(self, request, context):
        """lane interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHeading(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRoadWidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRelativeWidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HdmapImplServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LoadMap': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadMap,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapReply.SerializeToString,
            ),
            'ReleaseMap': grpc.unary_unary_rpc_method_handler(
                    servicer.ReleaseMap,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapReply.SerializeToString,
            ),
            'Reload': grpc.unary_unary_rpc_method_handler(
                    servicer.Reload,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadReply.SerializeToString,
            ),
            'GetMap': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMap,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapReply.SerializeToString,
            ),
            'GetElementById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetElementById,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdReply.SerializeToString,
            ),
            'GetElements': grpc.unary_unary_rpc_method_handler(
                    servicer.GetElements,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsReply.SerializeToString,
            ),
            'Getprojection': grpc.unary_unary_rpc_method_handler(
                    servicer.Getprojection,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionReply.SerializeToString,
            ),
            'GetPoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPoint,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointReply.SerializeToString,
            ),
            'GetHeading': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHeading,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingReply.SerializeToString,
            ),
            'GetWidth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWidth,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthReply.SerializeToString,
            ),
            'GetRoadWidth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRoadWidth,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthReply.SerializeToString,
            ),
            'GetRelativeWidth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRelativeWidth,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hdmap_lib.HdmapImpl', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HdmapImpl(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LoadMap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/LoadMap',
            proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReleaseMap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/ReleaseMap',
            proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/Reload',
            proto_dot_grpc_dot_hdmapimpl__pb2.ReloadRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.ReloadReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetMap',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetMapRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetMapReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetElementById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetElementById',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetElements(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetElements',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Getprojection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/Getprojection',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetPoint',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetPointRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetPointReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHeading(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetHeading',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetWidth',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRoadWidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetRoadWidth',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRelativeWidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetRelativeWidth',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from proto.hdmap_lib.proto import road_pb2
from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.attribute_impl import AttributesImpl

class LaneSectionImpl:
  def __init__(self) -> None:
    self._lane_ids = []
    self._index = -1
    self._road_id = 0
    
  def lanes(self):
    return self._lane_ids
  
  def index(self):
    return self._index
  
  def road_id(self):
    return self._road_id

class RoadImpl:
  def __init__(self) -> None:
    self._id = 0
    self._lane_sections = []
    self._junction_id = 0
    self._next_road_ids = []
    self._prev_road_ids = []
    self._prev_junction_id = 0
    self._next_junction_id = 0
    self._polygon = Polygon2d()
    self._attributes = AttributesImpl()
    self._name = ""
    self._type = road_pb2.Road.RoadType.UNKNOWN_ROAD
    self._road_struct = None
    self._schedule_poi_id = 0
    
  def id(self):
    return self._id
    
  def lane_sections(self):
    return self._lane_sections
  
  def junction(self):
    return self._junction_id
  
  def IsInJunction(self):
    return self._junction_id != 0
  
  def next_roads(self):
    return self._next_road_ids
  
  def prev_roads(self):
    return self._prev_road_ids
  
  def next_junction(self):
    return self._next_junction_id
  
  def prev_junction(self):
    return self._prev_junction_id
  
  def polygon(self):
    return self._polygon
  
  def attributes(self):
    return self._attributes
  
  def name(self):
    return self._name
  
  def type(self):
    return self._type
  
  def road_struct(self):
    return self._road_struct
  
  def poi(self):
    return self._schedule_poi_id


class LaneLinkImpl:
  def __init__(self) -> None:
    self._from_lane_id = 0
    self._from_s = 0.0
    self._to_lane_id = 0
    self._to_s = 0.0
    
  def from_lane_id(self):
    return self._from_lane_id
  
  def from_s(self):
    return self._from_s
  
  def to_lane_id(self):
    return self._to_lane_id
  
  def to_s(self):
    return self._to_s


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/road.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/road.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n proto/hdmap_lib/proto/road.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a%proto/hdmap_lib/proto/attribute.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\".\n\x0bLaneSection\x12\x1f\n\x08lane_ids\x18\x01 \x03(\x0b\x32\r.hdmap_lib.Id\"\xf2\x08\n\x04Road\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12-\n\rlane_sections\x18\x02 \x03(\x0b\x32\x16.hdmap_lib.LaneSection\x12\"\n\x0bjunction_id\x18\x03 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\x10next_junction_id\x18\x05 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\x10prev_junction_id\x18\x06 \x01(\x0b\x32\r.hdmap_lib.Id\x12(\n\nattributes\x18\x04 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12\x0c\n\x04name\x18\x07 \x01(\t\x12&\n\x04type\x18\x08 \x01(\x0e\x32\x18.hdmap_lib.Road.RoadType\x12$\n\rprev_road_ids\x18\t \x03(\x0b\x32\r.hdmap_lib.Id\x12$\n\rnext_road_ids\x18\n \x03(\x0b\x32\r.hdmap_lib.Id\x12#\n\x07polygon\x18\x0b \x01(\x0b\x32\x12.hdmap_lib.Polygon\"\xd8\x05\n\x08RoadType\x12\x10\n\x0cUNKNOWN_ROAD\x10\x01\x12\x16\n\x12PORT_VERTICAL_ROAD\x10\x02\x12\x18\n\x14PORT_HORIZONTAL_ROAD\x10\x03\x12\x12\n\x0ePORT_YARD_ROAD\x10\x04\x12\x14\n\x10PORT_BRIDGE_ROAD\x10\x05\x12\x12\n\x0ePORT_DOCK_ROAD\x10\x06\x12\x16\n\x12PORT_REV_DOCK_ROAD\x10\x07\x12\x14\n\x10PORT_GIRDER_ROAD\x10\x08\x12\x18\n\x14PORT_REV_GIRDER_ROAD\x10\t\x12\x13\n\x0fPORT_CROSS_ROAD\x10\n\x12 \n\x1cPORT_YARD_ENTRANCE_EXIT_ROAD\x10\x0b\x12\"\n\x1ePORT_BRIDGE_ENTRANCE_EXIT_ROAD\x10\x0c\x12\x19\n\x15PORT_VESSEL_HEAD_ROAD\x10\r\x12\x19\n\x15PORT_VESSEL_TAIL_ROAD\x10\x0e\x12\x1e\n\x1aPORT_VESSEL_HEAD_TAIL_ROAD\x10\x0f\x12\x14\n\x10PORT_GANTRY_ROAD\x10\x10\x12\x13\n\x0fPORT_CRANE_ROAD\x10\x11\x12\x16\n\x12PORT_CHARGING_AREA\x10\x12\x12\x14\n\x10\x43ITY_NORMAL_ROAD\x10\x13\x12\x13\n\x0f\x43ITY_CROSS_ROAD\x10\x14\x12\r\n\tRAMP_ROAD\x10\x15\x12\x17\n\x13HIGHWAY_NORMAL_ROAD\x10\x16\x12\x0f\n\x0b\x42RIDGE_ROAD\x10\x17\x12\x0f\n\x0bTUNNEL_ROAD\x10\x18\x12\x10\n\x0c\x46LYOVER_ROAD\x10\x19\x12\x13\n\x0fROUNDABOUT_ROAD\x10\x1a\x12\x12\n\x0eLETT_TURN_ONLY\x10\x1b\x12\x13\n\x0fRIGHT_TURN_ONLY\x10\x1c\x12\x0f\n\x0bU_TURN_ONLY\x10\x1d\x12\"\n\x1ePARKING_LOT_ENTRANCE_EXIT_ROAD\x10\x1e\x12\x14\n\x10PARKING_LOT_ROAD\x10\x1f'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_ROAD_ROADTYPE = _descriptor.EnumDescriptor(
  name='RoadType',
  full_name='hdmap_lib.Road.RoadType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ROAD', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VERTICAL_ROAD', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_HORIZONTAL_ROAD', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_YARD_ROAD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_BRIDGE_ROAD', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_DOCK_ROAD', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_REV_DOCK_ROAD', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_GIRDER_ROAD', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_REV_GIRDER_ROAD', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_CROSS_ROAD', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_YARD_ENTRANCE_EXIT_ROAD', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_BRIDGE_ENTRANCE_EXIT_ROAD', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VESSEL_HEAD_ROAD', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VESSEL_TAIL_ROAD', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VESSEL_HEAD_TAIL_ROAD', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_GANTRY_ROAD', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_CRANE_ROAD', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_CHARGING_AREA', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITY_NORMAL_ROAD', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITY_CROSS_ROAD', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAMP_ROAD', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_NORMAL_ROAD', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_ROAD', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNNEL_ROAD', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLYOVER_ROAD', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUNDABOUT_ROAD', index=25, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LETT_TURN_ONLY', index=26, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN_ONLY', index=27, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN_ONLY', index=28, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_LOT_ENTRANCE_EXIT_ROAD', index=29, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_LOT_ROAD', index=30, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=615,
  serialized_end=1343,
)
_sym_db.RegisterEnumDescriptor(_ROAD_ROADTYPE)


_LANESECTION = _descriptor.Descriptor(
  name='LaneSection',
  full_name='hdmap_lib.LaneSection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_ids', full_name='hdmap_lib.LaneSection.lane_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=202,
)


_ROAD = _descriptor.Descriptor(
  name='Road',
  full_name='hdmap_lib.Road',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Road.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_sections', full_name='hdmap_lib.Road.lane_sections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='hdmap_lib.Road.junction_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_junction_id', full_name='hdmap_lib.Road.next_junction_id', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_junction_id', full_name='hdmap_lib.Road.prev_junction_id', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Road.attributes', index=5,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='hdmap_lib.Road.name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Road.type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_road_ids', full_name='hdmap_lib.Road.prev_road_ids', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_road_ids', full_name='hdmap_lib.Road.next_road_ids', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Road.polygon', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROAD_ROADTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=1343,
)

_LANESECTION.fields_by_name['lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['lane_sections'].message_type = _LANESECTION
_ROAD.fields_by_name['junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['next_junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['prev_junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_ROAD.fields_by_name['type'].enum_type = _ROAD_ROADTYPE
_ROAD.fields_by_name['prev_road_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['next_road_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_ROAD_ROADTYPE.containing_type = _ROAD
DESCRIPTOR.message_types_by_name['LaneSection'] = _LANESECTION
DESCRIPTOR.message_types_by_name['Road'] = _ROAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneSection = _reflection.GeneratedProtocolMessageType('LaneSection', (_message.Message,), {
  'DESCRIPTOR' : _LANESECTION,
  '__module__' : 'proto.hdmap_lib.proto.road_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneSection)
  })
_sym_db.RegisterMessage(LaneSection)

Road = _reflection.GeneratedProtocolMessageType('Road', (_message.Message,), {
  'DESCRIPTOR' : _ROAD,
  '__module__' : 'proto.hdmap_lib.proto.road_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Road)
  })
_sym_db.RegisterMessage(Road)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/stop_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/stop_line.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/stop_line.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\"F\n\x08StopLine\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1f\n\x05\x63urve\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Curve'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])




_STOPLINE = _descriptor.Descriptor(
  name='StopLine',
  full_name='hdmap_lib.StopLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.StopLine.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve', full_name='hdmap_lib.StopLine.curve', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=192,
)

_STOPLINE.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_STOPLINE.fields_by_name['curve'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
DESCRIPTOR.message_types_by_name['StopLine'] = _STOPLINE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopLine = _reflection.GeneratedProtocolMessageType('StopLine', (_message.Message,), {
  'DESCRIPTOR' : _STOPLINE,
  '__module__' : 'proto.hdmap_lib.proto.stop_line_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.StopLine)
  })
_sym_db.RegisterMessage(StopLine)


# @@protoc_insertion_point(module_scope)



from enum import Enum
import sys
import os
sys.path.append(os.path.dirname(os.path.dirname(__file__)))
from pyhdmap.remote.remote_manager import RemoteManager
from pyhdmap.local.local_manager import LocalManager
from pyhdmap.utils.singleton import Singleton

class Mode(Enum):
  LOCAL = 1
  REMOTE = 2
  
class Point:
  def __init__(self, x:float, y:float) -> None:
    self._x = x
    self._y = y
    
  def x(self):
    return self._x
  
  def y(self):
    return self._y

@Singleton
class PyHDMap(object):
  def __init__(self) -> None:
    self._mode = None
    self._remote_manager = RemoteManager()
    self._local_manager = LocalManager()
    print("pyhdmap init finish")
    
  def set_mode(self, mode:Mode):
    self._mode = mode
    
  def get_manager(self):
    if self._mode == Mode.REMOTE:
      return self._remote_manager
    else:
      return self._local_manager
    return None
  


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/road_link.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/road_link.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/road_link.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\"\x87\x02\n\x08RoadLink\x12\x1f\n\x08junction\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12 \n\tfrom_road\x18\x02 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1e\n\x07to_road\x18\x03 \x01(\x0b\x32\r.hdmap_lib.Id\x12/\n\tturn_type\x18\x04 \x01(\x0e\x32\x1c.hdmap_lib.RoadLink.TurnType\"g\n\x08TurnType\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0c\n\x08STRAIGHT\x10\x02\x12\r\n\tLEFT_TURN\x10\x03\x12\x0f\n\x0bLEFT_U_TURN\x10\x04\x12\x0e\n\nRIGHT_TURN\x10\x05\x12\x10\n\x0cRIGHT_U_TURN\x10\x06'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_ROADLINK_TURNTYPE = _descriptor.EnumDescriptor(
  name='TurnType',
  full_name='hdmap_lib.RoadLink.TurnType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_U_TURN', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_U_TURN', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=245,
  serialized_end=348,
)
_sym_db.RegisterEnumDescriptor(_ROADLINK_TURNTYPE)


_ROADLINK = _descriptor.Descriptor(
  name='RoadLink',
  full_name='hdmap_lib.RoadLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='junction', full_name='hdmap_lib.RoadLink.junction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_road', full_name='hdmap_lib.RoadLink.from_road', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_road', full_name='hdmap_lib.RoadLink.to_road', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_type', full_name='hdmap_lib.RoadLink.turn_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROADLINK_TURNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=348,
)

_ROADLINK.fields_by_name['junction'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROADLINK.fields_by_name['from_road'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROADLINK.fields_by_name['to_road'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROADLINK.fields_by_name['turn_type'].enum_type = _ROADLINK_TURNTYPE
_ROADLINK_TURNTYPE.containing_type = _ROADLINK
DESCRIPTOR.message_types_by_name['RoadLink'] = _ROADLINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RoadLink = _reflection.GeneratedProtocolMessageType('RoadLink', (_message.Message,), {
  'DESCRIPTOR' : _ROADLINK,
  '__module__' : 'proto.hdmap_lib.proto.road_link_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.RoadLink)
  })
_sym_db.RegisterMessage(RoadLink)


# @@protoc_insertion_point(module_scope)



from proto.hdmap_lib.proto import lane_pb2
from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from pyhdmap.remote.grpc_client import HDMapClient
from pyhdmap.remote.hdmap_impl.geometry import CurveImpl
from pyhdmap.remote.hdmap_impl.attribute_impl import AttributesImpl

hdmap_client = HDMapClient()

class LaneImpl:
  
  def __init__(self) -> None:
    self._id = 0
    self._type = lane_pb2.Lane.Type.NONE
    self._turn_type = lane_pb2.Lane.TurnType.NO_TURN
    self._speed_info = None
    self._junction_id = 0
    self._left_boundary = CurveImpl()
    self._right_boundary = CurveImpl()
    self._central_line:list[Vec2d] = []
    self._reference_line:ReferenceLine = None
    self._successor_lane_links = []
    self._predecessor_lane_links = []
    self._left_neighbor_forward_id = 0
    self._left_neighbor_forward_driving_id = 0
    self._right_neighbor_forward_id = 0
    self._right_neighbor_forward_driving_id = 0
    self._left_neighbor_reverse_ids = []
    self._right_neighbor_reverse_ids = []
    self._polygon = Polygon2d()
    self._attrbutes = AttributesImpl()
    self._lane_section = None
    self._road = None
    self._lane_priority = 0
    self._rank = 0
    self._bi_direction_lane_id = 0
    
    # relations
    self._lanes:list[RelationImpl] = []
    self._stop_lines:list[RelationImpl] = []
    self._cross_walks:list[RelationImpl] = []
    self._pois:list[RelationImpl] = []
    self._parking_spaces:list[RelationImpl] = []
    self._objects:list[RelationImpl] = []
    self._clear_areas:list[RelationImpl] = []
    self._junctions:list[RelationImpl] = []
  
  def id(self):
    return self._id
  
  def type(self):
    return self._type
  
  def turn_type(self):
    return self._turn_type
  
  def max_speed(self):
    return self._speed_info.max
  
  def min_speed(self):
    return self._speed_info.min
  
  def junction_id(self):
    return self._junction_id
  
  def IsInJunction(self):
    return self._junction_id == 0
  
  def left_boundary(self):
    return self._left_boundary
  
  def right_boundary(self):
    return self._right_boundary
  
  def central_line(self):
    return self._central_line

  def reference_line(self):
    if self._reference_line == None:
      Utils.BuildReferenceLineFromPoints(self._central_line, self._reference_line)
    return self._reference_line  
  
  def length(self):
    if self._reference_line == None:
      Utils.BuildReferenceLineFromPoints(self._central_line, self._reference_line)
    return self._reference_line.length()  
  
  def lane_section(self):
    return self._lane_section
  
  def road(self):
    return self._road
  
  def successor_lane_links(self):
    return self._successor_lane_links
  
  def predecessor_lane_links(self):
    return self._predecessor_lane_links
  
  def left_neighbor_forward_lane(self):
    return self._left_neighbor_forward_id
  
  def left_neighbor_forward_driving_lane(self):
    return self._left_neighbor_forward_driving_id
  
  def right_neighbor_forward_lane(self):
    return self._right_neighbor_forward_id
  
  def right_neighbor_forward_driving_lane(self):
    return self._right_neighbor_forward_driving_id
  
  def left_neighbor_reverse_lane_ids(self):
    return self._left_neighbor_reverse_ids
  
  def right_neighbor_reverse_lane_ids(self):
    return self._right_neighbor_reverse_ids
  
  def lanes(self):
    return self._lanes
  
  def stop_lines(self):
    return self._stop_lines
  
  def cross_walks(self):
    return self._cross_walks
  
  def pois(self):
    return self._pois
  
  def pull_over_regions(self):
    return self._pull_over_regions
  
  def parking_spaces(self):
    return self._parking_spaces
  
  def objects(self):
    return self._objects
  
  def junctions(self):
    return self._junctions  
  
  def GetProjection(self, point:Vec2d):
    res = hdmap_client.get_lane_projection(self._id, point.x(), point.y())
    return res.s, res.d
  
  def GetPoint(self, s, d):
    res = hdmap_client.get_lane_point(self._id, s, d)
    return Vec2d(res.x, res.y)
  
  def GetHeading(self, s):
    res = hdmap_client.get_lane_heading(self._id, s)
    return res.heading
  
  def GetWidth(self, s):
    res = hdmap_client.get_lane_width(self._id, s)
    return res.left_width, res.right_width
  
  def GetRoadWidth(self, s):
    res = hdmap_client.get_lane_road_width(self._id, s)
    return res.left_width, res.right_width
  
  def GetRelativeWidth(self, point:Vec2d, heading):
    res = hdmap_client.get_lane_relative_width(self._id, point.x(), point.y(), heading)
    return res.left_relative_width, res.right_relative_width
    
    


import os
from typing import List, Tuple

from externals import libhdmap
from externals.libhdmap import *
from pyhdmap.utils.singleton import Singleton
from pyhdmap.utils.exception import except_output
from pyhdmap.utils.vessel import Vessel
from pyhdmap.remote.grpc_client import HDMapClient
from pyhdmap.remote.impl_cache import ImplCache
from pyhdmap.remote.common import *

@Singleton
class RemoteManager:
  
  def __init__(self):
    self._remote_ip = "[::]"
    self._remote_port = "50051"
    self._business_scene = ""
    self._map_impls = ImplCache()
    self._hdmap_client = HDMapClient()
    print("remote manager init finish")
    
  def set_config(self, ip, port, scene):
    self._remote_ip = ip
    self._remote_port = port
    self._business_scene = scene
    self._map_impls.set_config(ip, port, scene)
    
  ## basic method
  @except_output()
  def LoadMap(self):
    return self._hdmap_client.LoadMap()
  
  @except_output()
  def ReleaseMap(self):
    return self._hdmap_client.ReleaseMap()
    
  @except_output
  def Reload(self, vessels:List[Vessel]):
    return self._hdmap_client.Reload(vessels)
  
  @except_output
  def GetMap(self):
    if self._map_impls._map_info_generated == False:
      response = self._hdmap_client.GetMap()
      self._map_impls.build_impls_from_getmap_response(response)
    map_info = self._map_impls._map_info
    return map_info
  
  @except_output
  def GetLaneById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("lane", id))
  
  @except_output
  def GetRoadById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("road", id))
    
  @except_output
  def GetJunctionById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("junction", id))
  
  @except_output
  def GetObjectById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("object", id))    
    
  @except_output
  def GetCrosswalkById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("crosswalk", id))

  @except_output
  def GetParkingSpaceById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("parking_space", id))
  
  @except_output
  def GetPoiById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("poi", id))
  
  @except_output
  def GetPullOverRegionById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("pull_over_region", id))
  
  @except_output
  def GetSignalById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("signal", id))
  
  @except_output
  def GetStopLineById(self, id:int):
    return ToInfo(self._map_impls.get_impl_by_ids("stop_line", id))
  
  @except_output
  def GetLanes(self, point, distance):
    response = self._hdmap_client.get_elements(point, distance, "lane")
    if response.status == False:
      pass
    else:
      self._map_impls.build_impls_from_proto(response, "lane")
      return True
    
  @except_output
  def GetJunctions(self, point, distance):
    response = self._hdmap_client.get_elements(point, distance, "junction")
    if response.status == False:
      pass
    else:
      self._map_impls.build_impls_from_proto(response, "junction")
      return True
    
  @except_output
  def GetObjects(self, point, distance):
    response = self._hdmap_client.get_elements(point, distance, "object")
    if response.status == False:
      pass
    else:
      self._map_impls.build_impls_from_proto(response, "object")
      return True
    
  @except_output
  def GetCrosswalks(self, point, distance):
    response = self._hdmap_client.get_elements(point, distance, "crosswalk")
    if response.status == False:
      pass
    else:
      self._map_impls.build_impls_from_proto(response, "crosswalk")
      return True
    
  @except_output
  def GetParkingSpaces(self, point, distance):
    response = self._hdmap_client.get_elements(point, distance, "parking_space")
    if response.status == False:
      pass
    else:
      self._map_impls.build_impls_from_proto(response, "parking_space")
      return True
    
  


from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.lane_impl import LaneImpl
from pyhdmap.remote.hdmap_impl.road_impl import RoadImpl, LaneSectionImpl
from pyhdmap.remote.hdmap_impl.junction_impl import JunctionImpl
from pyhdmap.remote.hdmap_impl.object_impl import ObjectImpl
from pyhdmap.remote.hdmap_impl.crosswalk_impl import CrosswalkImpl
from pyhdmap.remote.hdmap_impl.parking_space_impl import ParkingSpaceImpl, LanePoint
from pyhdmap.remote.hdmap_impl.poi_impl import PoiImpl
from pyhdmap.remote.hdmap_impl.pull_over_region_impl import PullOverRegionImpl
from pyhdmap.remote.hdmap_impl.signal_impl import SignalImpl
from pyhdmap.remote.hdmap_impl.stop_line_impl import StopLineImpl
from pyhdmap.remote.hdmap_impl.lane_link_impl import LaneLinkImpl
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from pyhdmap.remote.hdmap_impl.attribute_impl import AttributesImpl
from pyhdmap.remote.hdmap_impl.geometry import *
from proto.hdmap_lib.proto import relation_pb2, geometry_pb2

def build_curve(lines, line_string_datas:dict):
  curve = CurveImpl()
  line_string_data_impls = []
  for line in lines:
    line_string_impl = LineStringImpl()
    line_string_impl._id = line.id.id
    line_string_impl._is_reverse = line.is_reverse
    curve._lines.append(line_string_impl)
    line_string_data_impl = LineStringDataImpl()
    line_string_data_impl._id  = line.id.id
    line_string_data = line_string_datas[line.id.id]
    for point in line_string_data.points:
      line_string_data_impl._points.append(Vec2d(point.x, point.y))
    line_string_data_impls.append(line_string_data_impl)
    
  return curve, line_string_data_impls

def build_attributes(attribute_proto):
  attribute_impl = AttributesImpl()
  for attribute in attribute_proto:
    attribute_impl.SetAttribute(attribute.key, attribute.value)
    
  return attribute_impl
  
def build_lane_link(lane_link_proto):
  lane_link_impl = LaneLinkImpl()
  lane_link_impl._from_lane_id = lane_link_proto.from_lane.id
  lane_link_impl._from_s = lane_link_proto.from_s
  lane_link_impl._to_lane_id = lane_link_proto.to_lane.id
  lane_link_impl._to_s = lane_link_proto.to_s
  return lane_link_impl

def build_polygon(polygon_proto, lines:dict):
  polygon_points = []
  for line in polygon_proto.lines:
    line_string_data = lines[line.id.id]
    for point in line_string_data.points:
      polygon_points.append(Vec2d(point.x, point.y))
  
  return Polygon2d(polygon_points)
  

def build_lane_section(lane_section_proto, road_id, index):
  lane_section_impl = LaneSectionImpl()
  lane_section_impl._index = index
  lane_section_impl._road_id = road_id
  for lane_id in lane_section_proto.lane_ids:
    lane_section_impl._lane_ids.append(lane_id.id)
  return lane_section_impl


def build_lane_lane_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.lane_lane_overlap_info.one_lane.id.id \
                  if relation_proto.lane_lane_overlap_info.another_lane.id.id == this_id \
                  else relation_proto.lane_lane_overlap_info.another_lane.id.id
  return relation_impl

def build_lane_crosswalk_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.lane_crosswalk_overlap_info.lane.id.id \
                  if relation_proto.lane_crosswalk_overlap_info.crosswalk.id.id == this_id \
                  else relation_proto.lane_crosswalk_overlap_info.crosswalk.id.id
  return relation_impl

def build_lane_stop_line_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.lane_stop_line_overlap_info.one_lane.id.id \
                  if relation_proto.lane_stop_line_overlap_info.stop_line.id.id == this_id \
                  else relation_proto.lane_stop_line_overlap_info.stop_line.id.id
  return relation_impl

def build_lane_poi_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.lane_poi_relation_info.lane.id.id \
                  if relation_proto.lane_poi_relation_info.poi.id.id == this_id \
                  else relation_proto.lane_poi_relation_info.poi.id.id
  return relation_impl

def build_lane_object_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.lane_object_overlap_info.lane.id.id \
                  if relation_proto.lane_object_overlap_info.object.id.id == this_id \
                  else relation_proto.lane_object_overlap_info.object.id.id
  return relation_impl

def build_lane_junction_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.lane_junction_overlap_info.lane.id.id \
                  if relation_proto.lane_junction_overlap_info.junction.id.id == this_id \
                  else relation_proto.lane_junction_overlap_info.junction.id.id
  return relation_impl

def build_poi_parking_space_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.poi_parking_space_relation_info.poi.id.id \
                  if relation_proto.poi_parking_space_relation_info.parking_space.id.id == this_id \
                  else relation_proto.poi_parking_space_relation_info.parking_space.id.id
  return relation_impl

def build_poi_pull_over_region_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.poi_pull_over_region_relation_info.poi.id.id \
                  if relation_proto.poi_pull_over_region_relation_info.pull_over_region.id.id == this_id \
                  else relation_proto.poi_pull_over_region_relation_info.pull_over_region.id.id
  return relation_impl

def build_signal_stop_line_relation(relation_proto, this_id):
  relation_impl = RelationImpl()
  relation_impl._type = relation_proto.type
  relation_impl._this_id = this_id
  relation_impl._other_id = relation_proto.traffic_light_overlap_info.traffic_light.id.id \
                  if relation_proto.traffic_light_overlap_info.stop_line.id.id == this_id \
                  else relation_proto.traffic_light_overlap_info.stop_line.id.id
  return relation_impl

class Builder:

  @staticmethod
  def build_lane_impl(lane_proto, lines, relations, lane_links):
    lane_impl = LaneImpl()
    line_string_data_impls = []
    lane_impl._id = lane_proto.id.id
    lane_impl._type = lane_proto.type
    lane_impl._turn_type = lane_proto.turn_type
    lane_impl._speed_info = lane_proto.speed_info
    lane_impl._junction_id = lane_proto.junction_id
    
    central_line_data = lines[lane_proto.central_line]
    for point in central_line_data.points:
      lane_impl._central_line.append(Vec2d(point.x, point.y))
    
    lane_impl._left_boundary, left_line_data_impls = \
      build_curve(lane_proto.left_lane_marking.lines, lines)
    lane_impl._right_boundary, right_line_data_impls = \
      build_curve(lane_proto.right_lane_marking.lines, lines)
    line_string_data_impls.extend(left_line_data_impls)
    line_string_data_impls.extend(right_line_data_impls)
      
    for id in lane_proto.successor_lane_ids:
      lane_impl._successor_lane_ids.append(id.id)
      
    for id in lane_proto.predecessor_lane_ids:
      lane_impl._predecessor_lane_ids.append(id.id)
      
    lane_impl._left_neighbor_forward_id = lane_proto.left_neighbor_forward_lane_id.id
    lane_impl._right_neighbor_forward_id = lane_proto.right_neighbor_forward_lane_id.id
    lane_impl._left_neighbor_forward_driving_id = lane_proto.left_neighbor_forward_driving_lane_id.id
    lane_impl._right_neighbor_forward_driving_id = lane_proto.right_neighbor_forward_driving_lane_id.id
    
    for id in lane_proto.left_neighbor_reverse_lane_ids:
      lane_impl._left_neighbor_reverse_ids.append(id.id)
      
    for id in lane_proto.right_neighbor_reverse_lane_ids:
      lane_impl._right_neighbor_reverse_ids.append(id.id)
    lane_impl._lane_priority = lane_proto.priority
    lane_impl._rank = lane_proto.rank
    lane_impl._road = lane_proto.road_id
    lane_impl._lane_section = lane_proto.lane_section_index
    lane_impl._attrbutes = build_attributes(lane_proto.attributes)
    
    lane_impl._polygon = build_polygon(lane_proto.polygon, lines)
    
    for lane_link_proto in lane_links:
      lane_link_impl = build_lane_link(lane_link_proto)
      if lane_link_impl.from_lane_id() == lane_impl._id:
        lane_impl._successor_lane_links.append(lane_link_impl)
      else:
        lane_impl._predecessor_lane_links.append(lane_link_impl)
        
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_LANE:
        relation_impl = build_lane_lane_relation(relation_proto, lane_impl._id)
        lane_impl._lanes.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_CROSSWALK:
        relation_impl = build_lane_crosswalk_relation(relation_proto, lane_impl._id)
        lane_impl._cross_walks.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_STOP_LINE:
        relation_impl = build_lane_stop_line_relation(relation_proto, lane_impl._id)
        lane_impl._stop_lines.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_POI:
        relation_impl = build_lane_poi_relation(relation_proto, lane_impl._id)
        lane_impl._poi.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_OBJECT:
        relation_impl = build_lane_object_relation(relation_proto, lane_impl._id)
        lane_impl._objects.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_JUNCTION:
        relation_impl = build_lane_junction_relation(relation_proto, lane_impl._id)
        lane_impl._junctions.append(relation_impl)
    
    return lane_impl, line_string_data_impls
    
    
  @staticmethod
  def build_road_impl(road_proto, lines):
    road_impl = RoadImpl()
    road_impl._id = road_proto.id.id
    
    lane_section_index = 0
    for lane_section_proto in road_proto.lane_sections:
      lane_section_impl = build_lane_section(lane_section_proto, road_proto.id.id, lane_section_index)
      road_impl._lane_sections.append(lane_section_impl)
      lane_section_index += 1
    
    road_impl._junction_id = road_proto.junction_id.id
    road_impl._prev_junction_id = road_proto.prev_junction_id.id
    road_impl._next_junction_id = road_proto.next_junction_id.id
    for prev_road_id in road_proto.prev_road_ids:
      road_impl._prev_road_ids.append(prev_road_id.id)
    for next_road_id in road_proto.next_road_ids:
      road_impl._next_road_ids.append(next_road_id.id)
      
    road_impl._polygon = build_polygon(road_proto.polygon, lines)
    road_impl._attributes = build_attributes(road_proto.attributes)
    road_impl._name = road_proto.name
    road_impl._type = road_proto.type
    
    return road_impl
  
  @staticmethod
  def build_junction_impl(junction_proto, lines, relations):
    junction_impl = JunctionImpl()
    junction_impl._id = junction_proto.id.id
    junction_impl._polygon = build_polygon(junction_proto.polygon, lines)
    junction_impl._name = junction_proto.name
    junction_impl._is_virtual_junction = junction_proto.is_virtual_junction
    for road_id in junction_proto.road_ids:
      junction_impl._road_ids.append(road_id.id)
    
    for relation_proto in relations:  
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_JUNCTION:
          relation_impl = build_lane_junction_relation(relation_proto, junction_impl._id)
          junction_impl._lanes.append(relation_impl)
          
    junction_impl._attributes = build_attributes(junction_proto.attributes)
    
    return junction_impl
  
  @staticmethod
  def build_object_impl(object_proto, lines, relations):
    object_impl = ObjectImpl()
    object_impl._id = object_proto.id.id
    object_impl._type = object_proto.type
    object_impl._polygon = build_polygon(object_proto.polygon, lines)
    object_impl._height = object_proto.height
    
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_OBJECT:
        relation_impl = build_lane_object_relation(relation_proto, object_impl._id)
        object_impl._lanes.append(relation_impl)
    return object_impl
  
  @staticmethod
  def build_crosswalk_impl(crosswalk_proto, lines, relations):
    crosswalk_impl = CrosswalkImpl()
    line_string_data_impls = []
    crosswalk_impl._id = crosswalk_proto.id.id
    crosswalk_impl._left_boundary, left_line_data_impls = \
      build_curve(crosswalk_proto.left_boundary.lines, lines)
    crosswalk_impl._right_boundary, right_line_data_impls = \
      build_curve(crosswalk_proto.right_boundary.lines, lines)
    line_string_data_impls.extend(left_line_data_impls)
    line_string_data_impls.extend(right_line_data_impls)
    crosswalk_impl._polygon = build_polygon(crosswalk_proto.polygon, lines)
    crosswalk_impl._attributes = build_attributes(crosswalk_proto.attributes)
    
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_CROSSWALK:
        relation_impl = build_lane_crosswalk_relation(relation_proto, crosswalk_impl._id)
        crosswalk_impl._lanes.append(relation_impl)
    return crosswalk_impl, line_string_data_impls
  
  @staticmethod
  def build_parking_space_impl(parking_space_proto, lines, relations):
    parking_space_impl = ParkingSpaceImpl()
    line_string_data_impls = []
    parking_space_impl._id = parking_space_proto.id.id
    parking_space_impl._left_boundary, left_line_data_impls = \
      build_curve(parking_space_proto.left_boundary.lines, lines)
    parking_space_impl._right_boundary, right_line_data_impls = \
      build_curve(parking_space_proto.right_boundary.lines, lines)
    line_string_data_impls.extend(left_line_data_impls)
    line_string_data_impls.extend(right_line_data_impls)
    
    central_line_data = lines[parking_space_proto.central_line]
    for point in central_line_data.points:
      parking_space_impl._central_line.append(Vec2d(point.x, point.y))
    
    parking_space_impl._polygon = build_polygon(parking_space_proto.polygon, lines)
    
    for in_lane in parking_space_proto.in_lanes:
      parking_space_impl._in_lanes.append(LanePoint(in_lane.id.id, in_lane.s))
      
    for out_lane in parking_space_proto.out_lanes:
      parking_space_impl._out_lanes.append(LanePoint(out_lane.id.id, out_lane.s))
      
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_POI_PARKING_SPACE:
          relation_impl = build_poi_parking_space_relation(relation_proto, parking_space_impl._id)
          parking_space_impl._pois.append(relation_impl)
    
    return parking_space_impl, line_string_data_impls
  
  @staticmethod
  def build_poi_impl(poi_proto, relations):
    poi_impl = PoiImpl()
    poi_impl._id = poi_proto.id.id
    poi_impl._type = poi_proto.type
    poi_impl._name = poi_proto.name
    poi_impl._coordinate = Vec2d(poi_proto.coordinate.x, poi_proto.coordinate.y)
    
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_LANE_POI:
        relation_impl = build_lane_poi_relation(relation_proto, poi_impl._id)
        poi_impl._lanes.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_POI_PARKING_SPACE:
        relation_impl = build_poi_parking_space_relation(relation_proto, poi_impl._id)
        poi_impl._parking_spaces.append(relation_impl)
      elif relation_proto.type == relation_pb2.Relation.RelationType.RELATION_POI_PULL_OVER_REGION:
        relation_impl = build_poi_pull_over_region_relation(relation_proto, poi_impl._id)
        poi_impl._pull_over_regions.append(relation_impl)
    
    return poi_impl
  
  @staticmethod
  def build_pull_over_region_impl(pull_over_region_proto, relations):
    pull_over_region_impl = PullOverRegionImpl()
    pull_over_region_impl._id = pull_over_region_proto.id.id
    pull_over_region_impl._lane_id = pull_over_region_proto.lane_id.id
    pull_over_region_impl._start_s = pull_over_region_proto.start_s
    pull_over_region_impl._end_s = pull_over_region_proto.end_s
    pull_over_region_impl._d = pull_over_region_proto.d
    
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_POI_PULL_OVER_REGION:
        relation_impl = build_poi_pull_over_region_relation(relation_proto, pull_over_region_impl._id)
        pull_over_region_impl._pois.append(relation_impl)
    return pull_over_region_impl
  
  @staticmethod
  def build_signal_impl(signal_proto, lines, relations):
    signal_impl = SignalImpl()
    signal_impl._id = signal_proto.id.id
    signal_impl._polygon = build_polygon(signal_proto.boundary, lines)
    signal_impl._signal_type = signal_proto.signal_type
    signal_impl._combination_type = signal_proto.combination_type
    signal_impl._signal_center = Vec2d(signal_proto.coordinate.x, signal_proto.coordinate.y)
    
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_TRAFFIC_LIGHT_STOP_LINE:
        relation_impl = build_signal_stop_line_relation(relation_proto, signal_impl._id)
        signal_impl._stop_lines.append(relation_impl)
        
    return signal_impl
  
  @staticmethod
  def build_stop_line_impl(stop_line_proto, lines, relations):
    stop_line_impl = StopLineImpl()
    line_string_data_impls = []
    stop_line_impl._id = stop_line_proto.id.id
    stop_line_impl._curve, line_string_datas = build_curve(stop_line_proto.curve, lines)
    line_string_data_impls.extend(line_string_datas)
    
    for relation_proto in relations:
      if relation_proto.type == relation_pb2.Relation.RelationType.RELATION_TRAFFIC_LIGHT_STOP_LINE:
        relation_impl = build_signal_stop_line_relation(relation_proto, stop_line_impl._id)
        stop_line_impl._signals.append(relation_impl)
    
    return stop_line_impl, line_string_data_impls


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/map.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import header_pb2 as proto_dot_hdmap__lib_dot_proto_dot_header__pb2
from proto.hdmap_lib.proto import crosswalk_pb2 as proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import junction_pb2 as proto_dot_hdmap__lib_dot_proto_dot_junction__pb2
from proto.hdmap_lib.proto import lane_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__pb2
from proto.hdmap_lib.proto import relation_pb2 as proto_dot_hdmap__lib_dot_proto_dot_relation__pb2
from proto.hdmap_lib.proto import road_pb2 as proto_dot_hdmap__lib_dot_proto_dot_road__pb2
from proto.hdmap_lib.proto import signal_pb2 as proto_dot_hdmap__lib_dot_proto_dot_signal__pb2
from proto.hdmap_lib.proto import stop_line_pb2 as proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2
from proto.hdmap_lib.proto import parking_space_pb2 as proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2
from proto.hdmap_lib.proto import poi_pb2 as proto_dot_hdmap__lib_dot_proto_dot_poi__pb2
from proto.hdmap_lib.proto import object_pb2 as proto_dot_hdmap__lib_dot_proto_dot_object__pb2
from proto.hdmap_lib.proto import lane_link_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2
from proto.hdmap_lib.proto import road_link_pb2 as proto_dot_hdmap__lib_dot_proto_dot_road__link__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/map.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fproto/hdmap_lib/proto/map.proto\x12\thdmap_lib\x1a\"proto/hdmap_lib/proto/header.proto\x1a%proto/hdmap_lib/proto/crosswalk.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a$proto/hdmap_lib/proto/junction.proto\x1a proto/hdmap_lib/proto/lane.proto\x1a$proto/hdmap_lib/proto/relation.proto\x1a proto/hdmap_lib/proto/road.proto\x1a\"proto/hdmap_lib/proto/signal.proto\x1a%proto/hdmap_lib/proto/stop_line.proto\x1a)proto/hdmap_lib/proto/parking_space.proto\x1a\x1fproto/hdmap_lib/proto/poi.proto\x1a\"proto/hdmap_lib/proto/object.proto\x1a%proto/hdmap_lib/proto/lane_link.proto\x1a%proto/hdmap_lib/proto/road_link.proto\"\xd4\x04\n\x03Map\x12!\n\x06header\x18\t \x01(\x0b\x32\x11.hdmap_lib.Header\x12\x1e\n\x05roads\x18\x01 \x03(\x0b\x32\x0f.hdmap_lib.Road\x12(\n\x05lines\x18\x02 \x03(\x0b\x32\x19.hdmap_lib.LineStringData\x12\x1e\n\x05lanes\x18\x03 \x03(\x0b\x32\x0f.hdmap_lib.Lane\x12&\n\tjunctions\x18\x04 \x03(\x0b\x32\x13.hdmap_lib.Junction\x12(\n\ncrosswalks\x18\x05 \x03(\x0b\x32\x14.hdmap_lib.Crosswalk\x12\"\n\x07signals\x18\x06 \x03(\x0b\x32\x11.hdmap_lib.Signal\x12\'\n\nstop_lines\x18\n \x03(\x0b\x32\x13.hdmap_lib.StopLine\x12/\n\x0eparking_spaces\x18\x0b \x03(\x0b\x32\x17.hdmap_lib.ParkingSpace\x12\x34\n\x11pull_over_regions\x18\x0c \x03(\x0b\x32\x19.hdmap_lib.PullOverRegion\x12\x1c\n\x04pois\x18\r \x03(\x0b\x32\x0e.hdmap_lib.Poi\x12\"\n\x07objects\x18\x0f \x03(\x0b\x32\x11.hdmap_lib.Object\x12&\n\trelations\x18\x08 \x03(\x0b\x32\x13.hdmap_lib.Relation\x12\'\n\nlane_links\x18\x10 \x03(\x0b\x32\x13.hdmap_lib.LaneLink\x12\'\n\nroad_links\x18\x11 \x03(\x0b\x32\x13.hdmap_lib.RoadLink'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_header__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_junction__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_lane__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_relation__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_road__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_signal__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_poi__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_object__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_road__link__pb2.DESCRIPTOR,])




_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='hdmap_lib.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hdmap_lib.Map.header', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roads', full_name='hdmap_lib.Map.roads', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.Map.lines', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes', full_name='hdmap_lib.Map.lanes', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junctions', full_name='hdmap_lib.Map.junctions', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalks', full_name='hdmap_lib.Map.crosswalks', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signals', full_name='hdmap_lib.Map.signals', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_lines', full_name='hdmap_lib.Map.stop_lines', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_spaces', full_name='hdmap_lib.Map.parking_spaces', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_regions', full_name='hdmap_lib.Map.pull_over_regions', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pois', full_name='hdmap_lib.Map.pois', index=10,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects', full_name='hdmap_lib.Map.objects', index=11,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='hdmap_lib.Map.relations', index=12,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_links', full_name='hdmap_lib.Map.lane_links', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_links', full_name='hdmap_lib.Map.road_links', index=14,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=1165,
)

_MAP.fields_by_name['header'].message_type = proto_dot_hdmap__lib_dot_proto_dot_header__pb2._HEADER
_MAP.fields_by_name['roads'].message_type = proto_dot_hdmap__lib_dot_proto_dot_road__pb2._ROAD
_MAP.fields_by_name['lines'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._LINESTRINGDATA
_MAP.fields_by_name['lanes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__pb2._LANE
_MAP.fields_by_name['junctions'].message_type = proto_dot_hdmap__lib_dot_proto_dot_junction__pb2._JUNCTION
_MAP.fields_by_name['crosswalks'].message_type = proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2._CROSSWALK
_MAP.fields_by_name['signals'].message_type = proto_dot_hdmap__lib_dot_proto_dot_signal__pb2._SIGNAL
_MAP.fields_by_name['stop_lines'].message_type = proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2._STOPLINE
_MAP.fields_by_name['parking_spaces'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PARKINGSPACE
_MAP.fields_by_name['pull_over_regions'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PULLOVERREGION
_MAP.fields_by_name['pois'].message_type = proto_dot_hdmap__lib_dot_proto_dot_poi__pb2._POI
_MAP.fields_by_name['objects'].message_type = proto_dot_hdmap__lib_dot_proto_dot_object__pb2._OBJECT
_MAP.fields_by_name['relations'].message_type = proto_dot_hdmap__lib_dot_proto_dot_relation__pb2._RELATION
_MAP.fields_by_name['lane_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2._LANELINK
_MAP.fields_by_name['road_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_road__link__pb2._ROADLINK
DESCRIPTOR.message_types_by_name['Map'] = _MAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
  'DESCRIPTOR' : _MAP,
  '__module__' : 'proto.hdmap_lib.proto.map_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Map)
  })
_sym_db.RegisterMessage(Map)


# @@protoc_insertion_point(module_scope)



from proto.hdmap_lib.proto import relation_pb2
from externals.libhdmap import *

class RelationImpl:
  def __init__(self) -> None:
    self._this_id = 0
    self._this_start_s = 0
    self._this_end_s = 0
    self._other_id = 0
    self._other_start_s = 0
    self._other_end_s = 0
    self._type = None
    
  def this_id(self):
    return self._this_id
  
  def this_lane_overlap_range(self):
    return Range(self._this_start_s, self._this_end_s)
  
  def other_id(self):
    return self._other_id
  
  def over_lane_overlap_range(self):
    return Range(self._other_start_s, self._other_end_s)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/crosswalk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/crosswalk.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/crosswalk.proto\x12\thdmap_lib\x1a%proto/hdmap_lib/proto/attribute.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\"\xc8\x01\n\tCrosswalk\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\rleft_boundary\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12(\n\x0eright_boundary\x18\x03 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12(\n\nattributes\x18\x04 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12#\n\x07polygon\x18\x05 \x01(\x0b\x32\x12.hdmap_lib.Polygon'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])




_CROSSWALK = _descriptor.Descriptor(
  name='Crosswalk',
  full_name='hdmap_lib.Crosswalk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Crosswalk.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='hdmap_lib.Crosswalk.left_boundary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='hdmap_lib.Crosswalk.right_boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Crosswalk.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Crosswalk.polygon', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=362,
)

_CROSSWALK.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_CROSSWALK.fields_by_name['left_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_CROSSWALK.fields_by_name['right_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_CROSSWALK.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_CROSSWALK.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
DESCRIPTOR.message_types_by_name['Crosswalk'] = _CROSSWALK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Crosswalk = _reflection.GeneratedProtocolMessageType('Crosswalk', (_message.Message,), {
  'DESCRIPTOR' : _CROSSWALK,
  '__module__' : 'proto.hdmap_lib.proto.crosswalk_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Crosswalk)
  })
_sym_db.RegisterMessage(Crosswalk)


# @@protoc_insertion_point(module_scope)



from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from proto.hdmap_lib.proto import signal_pb2

class SignalImpl:
  def __init__(self) -> None:
    self._id = 0
    self._polygon = Polygon2d()
    self._stop_lines:list[RelationImpl] = []
    self._signal_type = signal_pb2.Signal.SignalType.UNKNOWN_SIGNAL
    self._combination_type = signal_pb2.Signal.CombinationType.UNKNOWN_COMNINATION
    self._signal_center = Vec2d()
    
  def id(self):
    return self._id
  
  def polygon(self):
    return self._polygon
  
  def stop_lines(self):
    return self._stop_lines
  
  def signal_type(self):
    return self._signal_type
  
  def combination_type(self):
    return self._combination_type
  
  def signal_center(self):
    return self._signal_center


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/lane_link.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/lane_link.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/lane_link.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\"j\n\x08LaneLink\x12 \n\tfrom_lane\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0e\n\x06\x66rom_s\x18\x02 \x01(\x01\x12\x1e\n\x07to_lane\x18\x03 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0c\n\x04to_s\x18\x04 \x01(\x01'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])




_LANELINK = _descriptor.Descriptor(
  name='LaneLink',
  full_name='hdmap_lib.LaneLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_lane', full_name='hdmap_lib.LaneLink.from_lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_s', full_name='hdmap_lib.LaneLink.from_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_lane', full_name='hdmap_lib.LaneLink.to_lane', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_s', full_name='hdmap_lib.LaneLink.to_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=190,
)

_LANELINK.fields_by_name['from_lane'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANELINK.fields_by_name['to_lane'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
DESCRIPTOR.message_types_by_name['LaneLink'] = _LANELINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneLink = _reflection.GeneratedProtocolMessageType('LaneLink', (_message.Message,), {
  'DESCRIPTOR' : _LANELINK,
  '__module__' : 'proto.hdmap_lib.proto.lane_link_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneLink)
  })
_sym_db.RegisterMessage(LaneLink)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/object.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"proto/hdmap_lib/proto/object.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a%proto/hdmap_lib/proto/attribute.proto\"\xaa\x06\n\x06Object\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.hdmap_lib.Object.Type\x12#\n\x07polygon\x18\x03 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x12\x0e\n\x06height\x18\x04 \x01(\x01\x12\x0c\n\x04text\x18\x05 \x01(\t\x12/\n\ncross_type\x18\x06 \x01(\x0e\x32\x1b.hdmap_lib.Object.CrossType\x12(\n\nattributes\x18\x07 \x03(\x0b\x32\x14.hdmap_lib.Attribute\"\xdd\x03\n\x04Type\x12\x08\n\x04NONE\x10\x01\x12\r\n\tSIDE_WALK\x10\x02\x12\x11\n\rCHARGING_PILE\x10\x03\x12\x08\n\x04TEXT\x10\x04\x12\x0f\n\x0bGROUND_SIGN\x10\x05\x12\x0f\n\x0b\x42US_STATION\x10\x06\x12\x10\n\x0cTRAFFIC_SIGN\x10\x07\x12\x19\n\x15HEIGHT_LIMIT_OBSTACLE\x10\x08\x12\x0c\n\x08\x42UILDING\x10\t\x12\x15\n\x11\x44\x45\x43\x45LERATION_ZONE\x10\n\x12\x19\n\x15NON_SLIP_RAMP_MARKING\x10\x0b\x12\x12\n\x0e\x44IVERSION_LINE\x10\x0c\x12\x11\n\rLOCK_PAVILION\x10\r\x12\r\n\tREST_AREA\x10\x0e\x12\x16\n\x12WORKING_QUEUE_AREA\x10\x0f\x12\x11\n\rCHARGING_AREA\x10\x10\x12\x14\n\x10GRASS_GREEN_BELT\x10\x11\x12\x15\n\x11PEDESTRIAN_ISLAND\x10\x12\x12\x1a\n\x16\x45MERGENCY_PARKING_ZONE\x10\x13\x12\x12\n\x0e\x46ORBIDDEN_AREA\x10\x14\x12\x0e\n\nCLEAR_AREA\x10\x15\x12\x0e\n\nTRANSITION\x10\x16\x12\x0c\n\x08OBSTACLE\x10\x17\x12\x13\n\x0f\x42USH_GREEN_BELT\x10\x18\x12\x0f\n\x0b\x42RIDGE_EDGE\x10\x19\"a\n\tCrossType\x12\x15\n\x11VEHICLE_CAN_CROSS\x10\x01\x12\x15\n\x11\x42ICYCLE_CAN_CROSS\x10\x02\x12\x13\n\x0fHUMAN_CAN_CROSS\x10\x03\x12\x11\n\rCAN_NOT_CROSS\x10\x04'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,])



_OBJECT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.Object.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIDE_WALK', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHARGING_PILE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUND_SIGN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_STATION', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_SIGN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEIGHT_LIMIT_OBSTACLE', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUILDING', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECELERATION_ZONE', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NON_SLIP_RAMP_MARKING', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIVERSION_LINE', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCK_PAVILION', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REST_AREA', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORKING_QUEUE_AREA', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHARGING_AREA', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRASS_GREEN_BELT', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_ISLAND', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PARKING_ZONE', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORBIDDEN_AREA', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEAR_AREA', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSTACLE', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUSH_GREEN_BELT', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_EDGE', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=393,
  serialized_end=870,
)
_sym_db.RegisterEnumDescriptor(_OBJECT_TYPE)

_OBJECT_CROSSTYPE = _descriptor.EnumDescriptor(
  name='CrossType',
  full_name='hdmap_lib.Object.CrossType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_CAN_CROSS', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE_CAN_CROSS', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUMAN_CAN_CROSS', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_NOT_CROSS', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=872,
  serialized_end=969,
)
_sym_db.RegisterEnumDescriptor(_OBJECT_CROSSTYPE)


_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='hdmap_lib.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Object.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Object.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Object.polygon', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='hdmap_lib.Object.height', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='hdmap_lib.Object.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_type', full_name='hdmap_lib.Object.cross_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Object.attributes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBJECT_TYPE,
    _OBJECT_CROSSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=969,
)

_OBJECT.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_OBJECT.fields_by_name['type'].enum_type = _OBJECT_TYPE
_OBJECT.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_OBJECT.fields_by_name['cross_type'].enum_type = _OBJECT_CROSSTYPE
_OBJECT.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_OBJECT_TYPE.containing_type = _OBJECT
_OBJECT_CROSSTYPE.containing_type = _OBJECT
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'proto.hdmap_lib.proto.object_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Object)
  })
_sym_db.RegisterMessage(Object)


# @@protoc_insertion_point(module_scope)
